Download any file related to the class
download_any_file.RdThis function downloads any file related to the class from the class GitHub repository.
Arguments
- file_path_and_name
The name of the path and file to download.
- force_download
Will download and overwrite an existing file if the downloaded file has the same name.
- mode
A character indicating the mode with which to write the file. Useful values are "w", "wb" (binary), "a" (append) and "ab". Not used for methods "wget" and "curl". See also ‘Details’, notably about using "wb" for Windows. See download.file() mode argument.