Skip to contents

This function gets the root path where the class materials are stored. If the path has not been set, it will be set to a default location.

Usage

get_class_material_root_path()

Value

A string with the path to the root of the class materials directory.