Skip to contents

`r lifecycle::badge("deprecated")`

This function generates a fictional sample of data of sprinkles. This function was renamed rsprinkles() to be more consistent with other functions that generate random samples.

Usage

get_sprinkle_sample(n)

Arguments

n

The sample size.

Examples

 # Generate a sample from 10 sprinkle colors
 get_sprinkle_sample(10)
#> Error in deprecate_soft("0.2026.3", "get_sprinkle_sample()", "rsprinkles()"): could not find function "deprecate_soft"