Get the package name and version number
get_version.RdReturns the name of the package and the version number. This is useful to check that one is using the most recent version of the package in case the package is updated in the middle of the semester.