Skip to contents

This function takes one to the directory of a specific class. If the class files have not been downloaded yet, the user is prompted to download them from the class GitHub repository

Usage

goto_class(class_number)

Arguments

class_number

A number indicating which class we should get the code for.

Examples

 # Download code from the first class
 if (FALSE) goto_class(1) # \dontrun{}