Skip to contents

This function takes one to the directory of the final project. If the final project files have not been downloaded yet, the user is prompted to download them from the class GitHub repository

Usage

goto_final_project()

Examples

 # Download code from the final project
 if (FALSE) goto_final_project() # \dontrun{}