Skip to contents

This function takes one to the directory of a specific homework. If the homework has not been downloaded yet, the user is prompted to download it from the class GitHub repository.

Usage

goto_homework(homework_number)

Arguments

homework_number

A number indicating which homework directory to go to.

Examples

 # Download the first homework file
 if (FALSE) goto_homework(1) # \dontrun{}