Skip to contents

This function takes one to the directory of a specific practice session. If the practice ssion files have not been downloaded yet, the user is prompted to download them from the class GitHub repository

Usage

goto_practice_session(session_number)

Arguments

session_number

A number indicating which practice session should go to for.

Examples

 # Download code from the first practice session
 if (FALSE) goto_practice_session(1) # \dontrun{}