save_zip_of_all_class_material.Rd
This function creates a zip file of the entire class material directory, including all subdirectories and files.
save_zip_of_all_class_material()
#' \dontrun{save_zip_of_all_class_material()}