Get the root path for class materials
get_class_material_root_path.RdThis function gets the root path where the class materials are stored. If the path has not been set, it will be set to a default location.
get_class_material_root_path.RdThis function gets the root path where the class materials are stored. If the path has not been set, it will be set to a default location.