Generate a random sample of sprinkle colors
get_sprinkle_sample.Rd`r lifecycle::badge("deprecated")`
This function generates a fictional sample of data of sprinkles. This function was renamed rsprinkles() to be more consistent with other functions that generate random samples.