Go to the directory for a specific class
goto_class.RdThis function takes one to the directory of a specific class. If the class files have not been downloaded yet, the user is prompted to download them from the class GitHub repository
goto_class.RdThis function takes one to the directory of a specific class. If the class files have not been downloaded yet, the user is prompted to download them from the class GitHub repository