Sets the working directory and has RStudio file pane set to that directory If the directory does not exist, the user is prompted to download the files.
goto_directory.RdSets the working directory and has RStudio file pane set to that directory If the directory does not exist, the user is prompted to download the files.