Go to the directory for the final project
goto_final_project.RdThis function takes one to the directory of the final project. If the final project files have not been downloaded yet, the user is prompted to download them from the class GitHub repository