Go to the directory for specific homework
goto_homework.RdThis function takes one to the directory of a specific homework. If the homework has not been downloaded yet, the user is prompted to download it from the class GitHub repository.
goto_homework.RdThis function takes one to the directory of a specific homework. If the homework has not been downloaded yet, the user is prompted to download it from the class GitHub repository.