Go to the directory for a specific practice session
goto_practice_session.RdThis function takes one to the directory of a specific practice session. If the practice ssion files have not been downloaded yet, the user is prompted to download them from the class GitHub repository