Calculates the proportion of points in a vector greater than a specified value
pnull.RdCalculates the proportion of points in a vector greater than a specified value
Arguments
- obs_stat
An "observed statistic" value which will be used to assess how many points in the null_dist are greater than this value.
- null_dist
A vector of data consistent with a null hypothesis.
- lower.tail
A Boolean indicating whether one should return the proportion of points less than or equal to the obs_stat value.