Restore a backup from a zip file
restore_from_backup.RdThis function restores a backup from a specified zip file in the backup directory. #' @param backup_file_name The name of the backup zip file to restore. #' @return NULL
restore_from_backup.RdThis function restores a backup from a specified zip file in the backup directory. #' @param backup_file_name The name of the backup zip file to restore. #' @return NULL